==> 0.0.1.tar.gz: example/page/cupertino_slider.dart <==
import 'package:flutter/cupertino.dart';
import 'package:forme/forme.dart';

import 'package:forme_cupertino_fields/forme_cupertino_fields.dart';
import 'base_page.dart';

class CupertinoSliderPage extends BasePage<double, FormeCupertinoSliderModel> {
  @override
  Widget get body {
    return Column(
      children: [
        FormeCupertinoSlider(
          decoratorBuilder: FormeCupertinoInputDecoratorBuilder(
              prefix: null,
              wrapper: (child) {
                return Row(
                  children: [
                    Expanded(
                      child: child,
                    )
                  ],
                );
              }),
          autovalidateMode: AutovalidateMode.onUserInteraction,
          name: name,
          min: 1,
          max: 100,
          validator: FormeValidates.min(50, errorText: 'value must > 50'),
        ),
        ValueListenableBuilder(
            valueListenable: formKey.fieldListenable(name).valueListenable,
            builder: (context, value, _child) {
              return Text('$value');
            }),
        Wrap(
          children: [
            createButton('set min to 10', () {
              controller.updateModel(FormeCupertinoSliderModel(min: 10));
            }),
            createButton('set max to 50', () {
              controller.updateModel(FormeCupertinoSliderModel(max: 50));
            }),
            createButton('set divisions to 5', () {
              controller.updateModel(FormeCupertinoSliderModel(divisions: 5));
            }),
          ],
        )
      ],
    );
  }

  @override
  String get title => 'FormeCupertinoSlider';
}

==> 2.5.3.tar.gz: example/page/cupertino_slider.dart <==
import 'package:flutter/cupertino.dart';
import 'package:forme/forme.dart';

import 'package:forme_cupertino_fields/forme_cupertino_fields.dart';
import 'base_page.dart';

class CupertinoSliderPage extends BasePage<double, FormeCupertinoSliderModel> {
  @override
  Widget get body {
    return Column(
      children: [
        FormeCupertinoSlider(
          decoratorBuilder: FormeCupertinoInputDecoratorBuilder(
              prefix: null,
              wrapper: (child) {
                return Row(
                  children: [
                    Expanded(
                      child: child,
                    )
                  ],
                );
              }),
          name: name,
          min: 1,
          max: 100,
          listener: FormeValueFieldListener(
            autovalidateMode: AutovalidateMode.onUserInteraction,
            onValidate: FormeValidates.min(50, errorText: 'value must > 50'),
          ),
        ),
        Builder(builder: (context) {
          return ValueListenableBuilder(
              valueListenable: formKey.valueField(name).valueListenable,
              builder: (context, value, _child) {
                return Text('$value');
              });
        }),
        Wrap(
          children: [
            createButton('set min to 10', () {
              controller.updateModel(FormeCupertinoSliderModel(min: 10));
            }),
            createButton('set max to 50', () {
              controller.updateModel(FormeCupertinoSliderModel(max: 50));
            }),
            createButton('set divisions to 5', () {
              controller.updateModel(FormeCupertinoSliderModel(divisions: 5));
            }),
          ],
        )
      ],
    );
  }

  @override
  String get title => 'FormeCupertinoSlider';
}
